package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Oct 15, 2023
License: LGPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Name struct {
Cyrillic string `json:"cyrillic"`
Latin string `json:"latin"`
}
type Sex struct {
Code int `json:"code"`
Name Name `json:"name"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.